@@ -6,19 +6,19 @@
  fee is hereby granted, provided that the above copyright
  notice appear in all copies and that both that copyright
  notice and this permission notice appear in supporting
- documentation, and that the name of Silicon Graphics not be 
- used in advertising or publicity pertaining to distribution 
+ documentation, and that the name of Silicon Graphics not be
+ used in advertising or publicity pertaining to distribution
  of the software without specific prior written permission.
- Silicon Graphics makes no representation about the suitability 
+ Silicon Graphics makes no representation about the suitability
  of this software for any purpose. It is provided "as is"
  without any express or implied warranty.
- 
- SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS 
- SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY 
+
+ SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL SILICON
- GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL 
- DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, 
- DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE 
+ GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
+ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
+ DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
  OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
  THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
@@ -31,6 +31,8 @@
 #include "misc.h"
 #include "alias.h"
 
+static Bool high_keycode_warned;
+
 char *
 longText(unsigned long val, unsigned format)
 {
@@ -87,7 +89,7 @@ static void HandleKeycodesFile(XkbFile * file,
                                KeyNamesInfo * info);
 
 static void
-InitIndicatorNameInfo(IndicatorNameInfo * ii, KeyNamesInfo * info)
+InitIndicatorNameInfo(IndicatorNameInfo *ii, const KeyNamesInfo *info)
 {
     ii->defs.defined = 0;
     ii->defs.merge = info->merge;
@@ -115,7 +117,7 @@ NextIndicatorName(KeyNamesInfo * info)
 {
     IndicatorNameInfo *ii;
 
-    ii = uTypedAlloc(IndicatorNameInfo);
+    ii = malloc(sizeof(IndicatorNameInfo));
     if (ii)
     {
         InitIndicatorNameInfo(ii, info);
@@ -128,9 +130,7 @@ NextIndicatorName(KeyNamesInfo * info)
 static IndicatorNameInfo *
 FindIndicatorByIndex(KeyNamesInfo * info, int ndx)
 {
-    IndicatorNameInfo *old;
-
-    for (old = info->leds; old != NULL;
+    for (IndicatorNameInfo *old = info->leds; old != NULL;
          old = (IndicatorNameInfo *) old->defs.next)
     {
         if (old->ndx == ndx)
@@ -142,9 +142,7 @@ FindIndicatorByIndex(KeyNamesInfo * info, int ndx)
 static IndicatorNameInfo *
 FindIndicatorByName(KeyNamesInfo * info, Atom name)
 {
-    IndicatorNameInfo *old;
-
-    for (old = info->leds; old != NULL;
+    for (IndicatorNameInfo *old = info->leds; old != NULL;
          old = (IndicatorNameInfo *) old->defs.next)
     {
         if (old->name == name)
@@ -158,7 +156,6 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
 {
     IndicatorNameInfo *old;
     Bool replace;
-    const char *action;
 
     replace = (new->defs.merge == MergeReplace) ||
         (new->defs.merge == MergeOverride);
@@ -168,7 +165,7 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
         if (((old->defs.fileID == new->defs.fileID) && (warningLevel > 0))
             || (warningLevel > 9))
         {
-            WARN1("Multiple indicators named %s\n",
+            WARN("Multiple indicators named %s\n",
                   XkbAtomText(NULL, new->name, XkbMessage));
             if (old->ndx == new->ndx)
             {
@@ -176,23 +173,22 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
                 {
                     if (replace)
                         old->virtual = new->virtual;
-                    action = "Using %s instead of %s\n";
+                    ACTION("Using %s instead of %s\n",
+                            (old->virtual ? "virtual" : "real"),
+                            (old->virtual ? "real" : "virtual"));
                 }
                 else
                 {
-                    action = "Identical definitions ignored\n";
+                    ACTION("Identical definitions ignored\n");
                 }
-                ACTION2(action, (old->virtual ? "virtual" : "real"),
-                        (old->virtual ? "real" : "virtual"));
                 return True;
             }
             else
             {
                 if (replace)
-                    action = "Ignoring %d, using %d\n";
+                    ACTION("Ignoring %d, using %d\n", old->ndx, new->ndx);
                 else
-                    action = "Using %d, ignoring %d\n";
-                ACTION2(action, old->ndx, new->ndx);
+                    ACTION("Using %d, ignoring %d\n", old->ndx, new->ndx);
             }
             if (replace)
             {
@@ -200,9 +196,7 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
                     info->leds = (IndicatorNameInfo *) old->defs.next;
                 else
                 {
-                    IndicatorNameInfo *tmp;
-                    tmp = info->leds;
-                    for (; tmp != NULL;
+                    for (IndicatorNameInfo *tmp = info->leds; tmp != NULL;
                          tmp = (IndicatorNameInfo *) tmp->defs.next)
                     {
                         if (tmp->defs.next == (CommonInfo *) old)
@@ -212,7 +206,7 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
                         }
                     }
                 }
-                uFree(old);
+                free(old);
             }
         }
     }
@@ -222,9 +216,9 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
         if (((old->defs.fileID == new->defs.fileID) && (warningLevel > 0))
             || (warningLevel > 9))
         {
-            WARN1("Multiple names for indicator %d\n", new->ndx);
+            WARN("Multiple names for indicator %d\n", new->ndx);
             if ((old->name == new->name) && (old->virtual == new->virtual))
-                action = "Identical definitions ignored\n";
+                ACTION("Identical definitions ignored\n");
             else
             {
                 const char *oldType, *newType;
@@ -247,7 +241,7 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
                     using = old->name;
                     ignoring = new->name;
                 }
-                ACTION4("Using %s %s, ignoring %s %s\n",
+                ACTION("Using %s %s, ignoring %s %s\n",
                         oldType, XkbAtomText(NULL, using, XkbMessage),
                         newType, XkbAtomText(NULL, ignoring, XkbMessage));
             }
@@ -263,7 +257,7 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
     new = NextIndicatorName(info);
     if (!new)
     {
-        WSGO1("Couldn't allocate name for indicator %d\n", new->ndx);
+        WSGO("Couldn't allocate name for indicator %d\n", old->ndx);
         ACTION("Ignored\n");
         return False;
     }
@@ -276,16 +270,15 @@ AddIndicatorName(KeyNamesInfo * info, IndicatorNameInfo * new)
 static void
 ClearKeyNamesInfo(KeyNamesInfo * info)
 {
-    if (info->name != NULL)
-        uFree(info->name);
+    free(info->name);
     info->name = NULL;
     info->computedMax = info->explicitMax = info->explicitMin = -1;
     info->computedMin = 256;
     info->effectiveMin = 8;
     info->effectiveMax = 255;
-    bzero((char *) info->names, sizeof(info->names));
-    bzero((char *) info->files, sizeof(info->files));
-    bzero((char *) info->has_alt_forms, sizeof(info->has_alt_forms));
+    bzero(info->names, sizeof(info->names));
+    bzero(info->files, sizeof(info->files));
+    bzero(info->has_alt_forms, sizeof(info->has_alt_forms));
     if (info->leds)
         ClearIndicatorNameInfo(info->leds, info);
     if (info->aliases)
@@ -305,11 +298,9 @@ InitKeyNamesInfo(KeyNamesInfo * info)
 }
 
 static int
-FindKeyByLong(KeyNamesInfo * info, unsigned long name)
+FindKeyByLong(const KeyNamesInfo *info, unsigned long name)
 {
-    register int i;
-
-    for (i = info->effectiveMin; i <= info->effectiveMax; i++)
+    for (int i = info->effectiveMin; i <= info->effectiveMax; i++)
     {
         if (info->names[i] == name)
             return i;
@@ -323,19 +314,21 @@ FindKeyByLong(KeyNamesInfo * info, unsigned long name)
  * Note that the key's name is stored as a long, the keycode is the index.
  */
 static Bool
-AddKeyName(KeyNamesInfo * info,
-           int kc,
-           char *name, unsigned merge, unsigned fileID, Bool reportCollisions)
+AddKeyName(KeyNamesInfo *info, int kc, const char *name,
+           unsigned merge, unsigned fileID, Bool reportCollisions)
 {
     int old;
     unsigned long lval;
 
     if ((kc < info->effectiveMin) || (kc > info->effectiveMax))
     {
-        ERROR2("Illegal keycode %d for name <%s>\n", kc, name);
-        ACTION2("Must be in the range %d-%d inclusive\n",
-                info->effectiveMin, info->effectiveMax);
-        return False;
+        if (!high_keycode_warned && warningLevel > 1)
+        {
+            INFO("Keycodes above %d (e.g. <%s>) are not supported by X and are ignored\n",
+                  kc, name);
+            high_keycode_warned = True;
+        }
+        return True;
     }
     if (kc < info->computedMin)
         info->computedMin = kc;
@@ -365,7 +358,7 @@ AddKeyName(KeyNamesInfo * info,
             else if (reportCollisions)
             {
                 WARN("Multiple identical key name definitions\n");
-                ACTION2("Later occurences of \"<%s> = %d\" ignored\n",
+                ACTION("Later occurrences of \"<%s> = %d\" ignored\n",
                         buf, kc);
             }
             return True;
@@ -374,8 +367,8 @@ AddKeyName(KeyNamesInfo * info,
         {
             if (reportCollisions)
             {
-                WARN1("Multiple names for keycode %d\n", kc);
-                ACTION2("Using <%s>, ignoring <%s>\n", buf, name);
+                WARN("Multiple names for keycode %d\n", kc);
+                ACTION("Using <%s>, ignoring <%s>\n", buf, name);
             }
             return True;
         }
@@ -383,8 +376,8 @@ AddKeyName(KeyNamesInfo * info,
         {
             if (reportCollisions)
             {
-                WARN1("Multiple names for keycode %d\n", kc);
-                ACTION2("Using <%s>, ignoring <%s>\n", name, buf);
+                WARN("Multiple names for keycode %d\n", kc);
+                ACTION("Using <%s>, ignoring <%s>\n", name, buf);
             }
             info->names[kc] = 0;
             info->files[kc] = 0;
@@ -400,16 +393,16 @@ AddKeyName(KeyNamesInfo * info,
             info->has_alt_forms[old] = True;
             if (reportCollisions)
             {
-                WARN1("Key name <%s> assigned to multiple keys\n", name);
-                ACTION2("Using %d, ignoring %d\n", kc, old);
+                WARN("Key name <%s> assigned to multiple keys\n", name);
+                ACTION("Using %d, ignoring %d\n", kc, old);
             }
         }
         else if (merge != MergeAltForm)
         {
             if ((reportCollisions) && (warningLevel > 3))
             {
-                WARN1("Key name <%s> assigned to multiple keys\n", name);
-                ACTION2("Using %d, ignoring %d\n", old, kc);
+                WARN("Key name <%s> assigned to multiple keys\n", name);
+                ACTION("Using %d, ignoring %d\n", old, kc);
                 ACTION
                     ("Use 'alternate' keyword to assign the same name to multiple keys\n");
             }
@@ -432,9 +425,6 @@ static void
 MergeIncludedKeycodes(KeyNamesInfo * into, KeyNamesInfo * from,
                       unsigned merge)
 {
-    register int i;
-    char buf[5];
-
     if (from->errorCount > 0)
     {
         into->errorCount += from->errorCount;
@@ -445,9 +435,11 @@ MergeIncludedKeycodes(KeyNamesInfo * into, KeyNamesInfo * from,
         into->name = from->name;
         from->name = NULL;
     }
-    for (i = from->computedMin; i <= from->computedMax; i++)
+    for (int i = from->computedMin; i <= from->computedMax; i++)
     {
         unsigned thisMerge;
+        char buf[5];
+
         if (from->names[i] == 0)
             continue;
         LongToKeyName(from->names[i], buf);
@@ -523,8 +515,7 @@ HandleIncludeKeycodes(IncludeStmt * stmt, XkbDescPtr xkb, KeyNamesInfo * info)
         HandleKeycodesFile(rtrn, xkb, MergeOverride, &included);
         if (stmt->stmt != NULL)
         {
-            if (included.name != NULL)
-                uFree(included.name);
+            free(included.name);
             included.name = stmt->stmt;
             stmt->stmt = NULL;
         }
@@ -537,11 +528,10 @@ HandleIncludeKeycodes(IncludeStmt * stmt, XkbDescPtr xkb, KeyNamesInfo * info)
     /* Do we have more than one include statement? */
     if ((stmt->next != NULL) && (included.errorCount < 1))
     {
-        IncludeStmt *next;
         unsigned op;
         KeyNamesInfo next_incl;
 
-        for (next = stmt->next; next != NULL; next = next->next)
+        for (IncludeStmt *next = stmt->next; next != NULL; next = next->next)
         {
             if ((next->file == NULL) && (next->map == NULL))
             {
@@ -578,23 +568,26 @@ HandleIncludeKeycodes(IncludeStmt * stmt, XkbDescPtr xkb, KeyNamesInfo * info)
  * e.g. <ESC> = 9
  */
 static int
-HandleKeycodeDef(KeycodeDef * stmt, unsigned merge, KeyNamesInfo * info)
+HandleKeycodeDef(const KeycodeDef *stmt, unsigned merge, KeyNamesInfo *info)
 {
     int code;
     ExprResult result;
 
     if (!ExprResolveInteger(stmt->value, &result, NULL, NULL))
     {
-        ACTION1("No value keycode assigned to name <%s>\n", stmt->name);
+        ACTION("No value keycode assigned to name <%s>\n", stmt->name);
         return 0;
     }
     code = result.ival;
     if ((code < info->effectiveMin) || (code > info->effectiveMax))
     {
-        ERROR2("Illegal keycode %d for name <%s>\n", code, stmt->name);
-        ACTION2("Must be in the range %d-%d inclusive\n",
-                info->effectiveMin, info->effectiveMax);
-        return 0;
+        if (!high_keycode_warned && warningLevel > 1)
+        {
+            INFO("Keycodes above %d (e.g. <%s>) are not supported by X and are ignored\n",
+                  code, stmt->name);
+            high_keycode_warned = True;
+        }
+        return 1;
     }
     if (stmt->merge != MergeDefault)
     {
@@ -616,7 +609,7 @@ HandleKeycodeDef(KeycodeDef * stmt, unsigned merge, KeyNamesInfo * info)
  * @return 1 on success, 0 otherwise.
  */
 static int
-HandleKeyNameVar(VarDef * stmt, KeyNamesInfo * info)
+HandleKeyNameVar(const VarDef *stmt, KeyNamesInfo *info)
 {
     ExprResult tmp, field;
     ExprDef *arrayNdx;
@@ -627,8 +620,8 @@ HandleKeyNameVar(VarDef * stmt, KeyNamesInfo * info)
 
     if (tmp.str != NULL)
     {
-        ERROR1("Unknown element %s encountered\n", tmp.str);
-        ACTION1("Default for field %s ignored\n", field.str);
+        ERROR("Unknown element %s encountered\n", tmp.str);
+        ACTION("Default for field %s ignored\n", field.str);
         return 0;
     }
     if (uStrCaseCmp(field.str, "minimum") == 0)
@@ -638,34 +631,42 @@ HandleKeyNameVar(VarDef * stmt, KeyNamesInfo * info)
     else
     {
         ERROR("Unknown field encountered\n");
-        ACTION1("Assigment to field %s ignored\n", field.str);
+        ACTION("Assignment to field %s ignored\n", field.str);
         return 0;
     }
     if (arrayNdx != NULL)
     {
-        ERROR1("The %s setting is not an array\n", field.str);
+        ERROR("The %s setting is not an array\n", field.str);
         ACTION("Illegal array reference ignored\n");
         return 0;
     }
 
     if (ExprResolveInteger(stmt->value, &tmp, NULL, NULL) == 0)
     {
-        ACTION1("Assignment to field %s ignored\n", field.str);
+        ACTION("Assignment to field %s ignored\n", field.str);
         return 0;
     }
-    if ((tmp.ival < XkbMinLegalKeyCode) || (tmp.ival > XkbMaxLegalKeyCode))
+    if ((tmp.ival < XkbMinLegalKeyCode))
     {
-        ERROR3
+        ERROR
             ("Illegal keycode %d (must be in the range %d-%d inclusive)\n",
              tmp.ival, XkbMinLegalKeyCode, XkbMaxLegalKeyCode);
-        ACTION1("Value of \"%s\" not changed\n", field.str);
+        ACTION("Value of \"%s\" not changed\n", field.str);
         return 0;
     }
+    if ((tmp.ival > XkbMaxLegalKeyCode))
+    {
+        WARN("Unsupported maximum keycode %d, clipping.\n", tmp.ival);
+        ACTION("X11 cannot support keycodes above 255.\n");
+        info->explicitMax = XkbMaxLegalKeyCode;
+        info->effectiveMax = XkbMaxLegalKeyCode;
+        return 1;
+    }
     if (which == MIN_KEYCODE_DEF)
     {
         if ((info->explicitMax > 0) && (info->explicitMax < tmp.ival))
         {
-            ERROR2
+            ERROR
                 ("Minimum key code (%d) must be <= maximum key code (%d)\n",
                  tmp.ival, info->explicitMax);
             ACTION("Minimum key code value not changed\n");
@@ -673,7 +674,7 @@ HandleKeyNameVar(VarDef * stmt, KeyNamesInfo * info)
         }
         if ((info->computedMax > 0) && (info->computedMin < tmp.ival))
         {
-            ERROR2
+            ERROR
                 ("Minimum key code (%d) must be <= lowest defined key (%d)\n",
                  tmp.ival, info->computedMin);
             ACTION("Minimum key code value not changed\n");
@@ -686,14 +687,14 @@ HandleKeyNameVar(VarDef * stmt, KeyNamesInfo * info)
     {
         if ((info->explicitMin > 0) && (info->explicitMin > tmp.ival))
         {
-            ERROR2("Maximum code (%d) must be >= minimum key code (%d)\n",
+            ERROR("Maximum code (%d) must be >= minimum key code (%d)\n",
                    tmp.ival, info->explicitMin);
             ACTION("Maximum code value not changed\n");
             return 0;
         }
         if ((info->computedMax > 0) && (info->computedMax > tmp.ival))
         {
-            ERROR2
+            ERROR
                 ("Maximum code (%d) must be >= highest defined key (%d)\n",
                  tmp.ival, info->computedMax);
             ACTION("Maximum code value not changed\n");
@@ -706,7 +707,7 @@ HandleKeyNameVar(VarDef * stmt, KeyNamesInfo * info)
 }
 
 static int
-HandleIndicatorNameDef(IndicatorNameDef * def,
+HandleIndicatorNameDef(const IndicatorNameDef *def,
                        unsigned merge, KeyNamesInfo * info)
 {
     IndicatorNameInfo ii;
@@ -715,7 +716,7 @@ HandleIndicatorNameDef(IndicatorNameDef * def,
     if ((def->ndx < 1) || (def->ndx > XkbNumIndicators))
     {
         info->errorCount++;
-        ERROR1("Name specified for illegal indicator index %d\n", def->ndx);
+        ERROR("Name specified for illegal indicator index %d\n", def->ndx);
         ACTION("Ignored\n");
         return False;
     }
@@ -787,14 +788,14 @@ HandleKeycodesFile(XkbFile * file,
         case StmtInterpDef:
         case StmtVModDef:
             ERROR("Keycode files may define key and indicator names only\n");
-            ACTION1("Ignoring definition of %s\n",
+            ACTION("Ignoring definition of %s\n",
                     ((stmt->stmtType ==
                       StmtInterpDef) ? "a symbol interpretation" :
                      "virtual modifiers"));
             info->errorCount++;
             break;
         default:
-            WSGO1("Unexpected statement type %d in HandleKeycodesFile\n",
+            WSGO("Unexpected statement type %d in HandleKeycodesFile\n",
                   stmt->stmtType);
             break;
         }
@@ -804,7 +805,7 @@ HandleKeycodesFile(XkbFile * file,
 #ifdef NOISY
             ERROR("Too many errors\n");
 #endif
-            ACTION1("Abandoning keycodes file \"%s\"\n", file->topName);
+            ACTION("Abandoning keycodes file \"%s\"\n", file->topName);
             break;
         }
     }
@@ -846,7 +847,7 @@ CompileKeycodes(XkbFile * file, XkbFileInfo * result, unsigned merge)
         if (XkbAllocNames(xkb, XkbKeyNamesMask | XkbIndicatorNamesMask, 0, 0)
                 == Success)
         {
-            register int i;
+            int i;
             xkb->names->keycodes = XkbInternAtom(xkb->dpy, info.name, False);
             uDEBUG2(1, "key range: %d..%d\n", xkb->min_key_code,
                     xkb->max_key_code);
@@ -878,8 +879,8 @@ CompileKeycodes(XkbFile * file, XkbFileInfo * result, unsigned merge)
                                   XkbAtomGetString(NULL, ii->name), False);
                 if (xkb->indicators != NULL)
                 {
-                    register unsigned bit;
-                    bit = 1 << (ii->ndx - 1);
+                    unsigned bit = 1U << (ii->ndx - 1);
+
                     if (ii->virtual)
                         xkb->indicators->phys_indicators &= ~bit;
                     else
