@@ -6,24 +6,25 @@
  fee is hereby granted, provided that the above copyright
  notice appear in all copies and that both that copyright
  notice and this permission notice appear in supporting
- documentation, and that the name of Silicon Graphics not be 
- used in advertising or publicity pertaining to distribution 
+ documentation, and that the name of Silicon Graphics not be
+ used in advertising or publicity pertaining to distribution
  of the software without specific prior written permission.
- Silicon Graphics makes no representation about the suitability 
+ Silicon Graphics makes no representation about the suitability
  of this software for any purpose. It is provided "as is"
  without any express or implied warranty.
- 
- SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS 
- SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY 
+
+ SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
  AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL SILICON
- GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL 
- DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, 
- DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE 
+ GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
+ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
+ DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
  OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
  THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
  ********************************************************/
 
+#include "utils.h"
 #include <stdio.h>
 #include <ctype.h>
 #include <X11/keysym.h>
@@ -34,10 +35,6 @@
 #include <unistd.h>
 /* end BR */
 
-#if defined(sgi)
-#include <malloc.h>
-#endif
-
 #define	DEBUG_VAR debugFlags
 #include "xkbcomp.h"
 #include <stdlib.h>
@@ -47,9 +44,6 @@
 #include "tokens.h"
 #include <X11/extensions/XKBgeom.h>
 
-#ifdef __UNIXOS2__
-#define chdir _chdir2
-#endif
 
 #ifdef WIN32
 #define S_IRGRP 0
@@ -73,7 +67,9 @@
 #define	INPUT_XKB	1
 #define	INPUT_XKM	2
 
+#ifdef DEBUG
 unsigned int debugFlags;
+#endif
 
 static const char *fileTypeExt[] = {
     "XXX",
@@ -84,12 +80,12 @@ static const char *fileTypeExt[] = {
 };
 
 static unsigned inputFormat, outputFormat;
-char *rootDir;
+static const char *rootDir;
 static char *inputFile;
-static char *inputMap;
+static const char *inputMap;
 static char *outputFile;
-static char *inDpyName;
-static char *outDpyName;
+static const char *inDpyName;
+static const char *outDpyName;
 static Display *inDpy;
 static Display *outDpy;
 static Bool showImplicit = False;
@@ -99,10 +95,10 @@ static Bool xkblist = False;
 unsigned warningLevel = 5;
 unsigned verboseLevel = 0;
 unsigned dirsToStrip = 0;
-unsigned optionalParts = 0;
-static char *preErrorMsg = NULL;
-static char *postErrorMsg = NULL;
-static char *errorPrefix = NULL;
+static unsigned optionalParts = 0;
+static const char *preErrorMsg = NULL;
+static const char *postErrorMsg = NULL;
+static const char *errorPrefix = NULL;
 static unsigned int device_id = XkbUseCoreKbd;
 
 /***====================================================================***/
@@ -181,7 +177,7 @@ Usage(int argc, char *argv[])
 /***====================================================================***/
 
 static void
-setVerboseFlags(char *str)
+setVerboseFlags(const char *str)
 {
     for (; *str; str++)
     {
@@ -205,7 +201,7 @@ setVerboseFlags(char *str)
         default:
             if (warningLevel > 4)
             {
-                WARN1("Unknown verbose option \"%c\"\n", (unsigned int) *str);
+                WARN("Unknown verbose option \"%c\"\n", (unsigned int) *str);
                 ACTION("Ignored\n");
             }
             break;
@@ -217,7 +213,7 @@ setVerboseFlags(char *str)
 static Bool
 parseArgs(int argc, char *argv[])
 {
-    register int i, tmp;
+    int i, tmp;
 
     i = strlen(argv[0]);
     tmp = strlen("xkblist");
@@ -228,7 +224,7 @@ parseArgs(int argc, char *argv[])
     for (i = 1; i < argc; i++)
     {
         int itmp;
-        if ((argv[i][0] != '-') || (uStringEqual(argv[i], "-")))
+        if ((argv[i][0] != '-') || (strcmp(argv[i], "-") == 0))
         {
             if (!xkblist)
             {
@@ -239,7 +235,7 @@ parseArgs(int argc, char *argv[])
                 else if (warningLevel > 0)
                 {
                     WARN("Too many file names on command line\n");
-                    ACTION3
+                    ACTION
                         ("Compiling %s, writing to %s, ignoring %s\n",
                          inputFile, outputFile, argv[i]);
                 }
@@ -269,7 +265,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple output file formats specified\n");
-                    ACTION1("\"%s\" flag ignored\n", argv[i]);
+                    ACTION("\"%s\" flag ignored\n", argv[i]);
                 }
             }
             else
@@ -287,7 +283,7 @@ parseArgs(int argc, char *argv[])
                 if (sscanf(argv[++i], "%i", &itmp) == 1)
                     debugFlags = itmp;
             }
-            INFO1("Setting debug flags to %d\n", debugFlags);
+            INFO("Setting debug flags to %d\n", debugFlags);
         }
 #endif
         else if ((strcmp(argv[i], "-dflts") == 0) && (!xkblist))
@@ -308,8 +304,8 @@ parseArgs(int argc, char *argv[])
             {
                 if (warningLevel > 0)
                 {
-                    WARN("Multiple pre-error messsages specified\n");
-                    ACTION2("Compiling %s, ignoring %s\n",
+                    WARN("Multiple pre-error messages specified\n");
+                    ACTION("Compiling %s, ignoring %s\n",
                             preErrorMsg, argv[i]);
                 }
             }
@@ -331,7 +327,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple error prefixes specified\n");
-                    ACTION2("Compiling %s, ignoring %s\n",
+                    ACTION("Compiling %s, ignoring %s\n",
                             errorPrefix, argv[i]);
                 }
             }
@@ -353,7 +349,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple post-error messages specified\n");
-                    ACTION2("Compiling %s, ignoring %s\n",
+                    ACTION("Compiling %s, ignoring %s\n",
                             postErrorMsg, argv[i]);
                 }
             }
@@ -384,7 +380,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple output file formats specified\n");
-                    ACTION1("\"%s\" flag ignored\n", argv[i]);
+                    ACTION("\"%s\" flag ignored\n", argv[i]);
                 }
             }
             else
@@ -410,7 +406,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("No map name specified\n");
-                    ACTION1("Trailing \"%s\" option ignored\n", argv[i - 1]);
+                    ACTION("Trailing \"%s\" option ignored\n", argv[i - 1]);
                 }
             }
             else if (xkblist)
@@ -423,7 +419,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple map names specified\n");
-                    ACTION2("Compiling %s, ignoring %s\n", inputMap, argv[i]);
+                    ACTION("Compiling %s, ignoring %s\n", inputMap, argv[i]);
                 }
             }
             else
@@ -448,7 +444,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple output files specified\n");
-                    ACTION2("Compiling %s, ignoring %s\n", outputFile,
+                    ACTION("Compiling %s, ignoring %s\n", outputFile,
                             argv[i]);
                 }
             }
@@ -463,13 +459,12 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("No optional components specified\n");
-                    ACTION1("Trailing \"%s\" option ignored\n", argv[i - 1]);
+                    ACTION("Trailing \"%s\" option ignored\n", argv[i - 1]);
                 }
             }
             else
             {
-                char *tmp2;
-                for (tmp2 = argv[i]; (*tmp2 != '\0'); tmp2++)
+                for (const char *tmp2 = argv[i]; (*tmp2 != '\0'); tmp2++)
                 {
                     switch (*tmp2)
                     {
@@ -496,10 +491,10 @@ parseArgs(int argc, char *argv[])
                     default:
                         if (warningLevel > 0)
                         {
-                            WARN1
+                            WARN
                                 ("Illegal component for %s option\n",
                                  argv[i - 1]);
-                            ACTION1
+                            ACTION
                                 ("Ignoring unknown specifier \"%c\"\n",
                                  (unsigned int) *tmp2);
                         }
@@ -525,7 +520,7 @@ parseArgs(int argc, char *argv[])
                 dirsToStrip = 0;
             }
             if (warningLevel > 5)
-                INFO1("Setting path count to %d\n", dirsToStrip);
+                INFO("Setting path count to %d\n", dirsToStrip);
         }
         else if (strncmp(argv[i], "-R", 2) == 0)
         {
@@ -542,7 +537,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple root directories specified\n");
-                    ACTION2("Using %s, ignoring %s\n", rootDir, argv[i]);
+                    ACTION("Using %s, ignoring %s\n", rootDir, argv[i]);
                 }
             }
             else
@@ -550,13 +545,16 @@ parseArgs(int argc, char *argv[])
                 rootDir = &argv[i][2];
                 if (warningLevel > 8)
                 {
-                    WARN1("Changing root directory to \"%s\"\n", rootDir);
+                    WARN("Changing root directory to \"%s\"\n", rootDir);
                 }
-                if ((chdir(rootDir) < 0) && (warningLevel > 0))
+                if (chdir(rootDir) == 0)
                 {
-                    WARN1("Couldn't change directory to \"%s\"\n", rootDir);
-                    ACTION("Root directory (-R) option ignored\n");
-                    rootDir = NULL;
+                    XkbAddDirectoryToPath(".");
+                } else if (warningLevel > 0)
+                {
+                       WARN("Couldn't change directory to \"%s\"\n", rootDir);
+                       ACTION("Root directory (-R) option ignored\n");
+                       rootDir = NULL;
                 }
             }
         }
@@ -567,7 +565,7 @@ parseArgs(int argc, char *argv[])
         }
         else if (strncmp(argv[i], "-v", 2) == 0)
         {
-            char *str;
+            const char *str;
             if (argv[i][2] != '\0')
                 str = &argv[i][2];
             else if ((i < (argc - 1)) && (argv[i + 1][0] != '-'))
@@ -579,17 +577,37 @@ parseArgs(int argc, char *argv[])
         }
         else if (strncmp(argv[i], "-w", 2) == 0)
         {
-            if ((i >= (argc - 1)) || (!isdigit(argv[i + 1][0])))
+            unsigned long utmp;
+            char *tmp2;
+            /* If text is just after "-w" in the same word, then it must
+             * be a number and it is the warning level. Otherwise, if the
+             * next argument is a number, then it is the warning level,
+             * else the warning level is assumed to be 0.
+             */
+            if (argv[i][2] == '\0')
             {
                 warningLevel = 0;
-                if (isdigit(argv[i][1]))
-                    if (sscanf(&argv[i][1], "%i", &itmp) == 1)
-                        warningLevel = itmp;
+                if (i < argc - 1)
+                {
+                    utmp = strtoul(argv[i+1], &tmp2, 10);
+                    if (argv[i+1][0] != '\0' && *tmp2 == '\0')
+                    {
+                        warningLevel = utmp > 10 ? 10 : utmp;
+                        i++;
+                    }
+                }
             }
             else
             {
-                if (sscanf(argv[++i], "%i", &itmp) == 1)
-                    warningLevel = itmp;
+                utmp = strtoul(&argv[i][2], &tmp2, 10);
+                if (*tmp2 == '\0')
+                    warningLevel = utmp > 10 ? 10 : utmp;
+                else
+                {
+                    ERROR("Unknown flag \"%s\" on command line\n", argv[i]);
+                    Usage(argc, argv);
+                    return False;
+                }
             }
         }
         else if ((strcmp(argv[i], "-xkb") == 0) && (!xkblist))
@@ -600,7 +618,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple output file formats specified\n");
-                    ACTION1("\"%s\" flag ignored\n", argv[i]);
+                    ACTION("\"%s\" flag ignored\n", argv[i]);
                 }
             }
             else
@@ -614,7 +632,7 @@ parseArgs(int argc, char *argv[])
                 if (warningLevel > 0)
                 {
                     WARN("Multiple output file formats specified\n");
-                    ACTION1("\"%s\" flag ignored\n", argv[i]);
+                    ACTION("\"%s\" flag ignored\n", argv[i]);
                 }
             }
             else
@@ -622,7 +640,7 @@ parseArgs(int argc, char *argv[])
         }
         else
         {
-            ERROR1("Unknown flag \"%s\" on command line\n", argv[i]);
+            ERROR("Unknown flag \"%s\" on command line\n", argv[i]);
             Usage(argc, argv);
             return False;
         }
@@ -634,7 +652,7 @@ parseArgs(int argc, char *argv[])
         ERROR("No input file specified\n");
         return False;
     }
-    else if (uStringEqual(inputFile, "-"))
+    else if (strcmp(inputFile, "-") == 0)
     {
         inputFormat = INPUT_XKB;
     }
@@ -671,12 +689,12 @@ parseArgs(int argc, char *argv[])
                 else
                 {
                     WARN("Map specified in filename and with -m flag\n");
-                    ACTION1("map from name (\"%s\") ignored\n", tmpstr);
+                    ACTION("map from name (\"%s\") ignored\n", tmpstr);
                 }
             }
             else
             {
-                ERROR1("Illegal name \"%s\" for input file\n", inputFile);
+                ERROR("Illegal name \"%s\" for input file\n", inputFile);
                 return False;
             }
         }
@@ -738,22 +756,27 @@ parseArgs(int argc, char *argv[])
             return False;
         }
     }
-    else if ((!outputFile) && (inputFile) && uStringEqual(inputFile, "-"))
+    else if ((!outputFile) && (inputFile) && (strcmp(inputFile, "-") == 0))
     {
-        int len = strlen("stdin") + strlen(fileTypeExt[outputFormat]) + 2;
-        outputFile = uTypedCalloc(len, char);
-        if (outputFile == NULL)
+#ifdef HAVE_ASPRINTF
+        if (asprintf(&outputFile, "stdin.%s", fileTypeExt[outputFormat]) < 0)
+#else
+        size_t len = strlen("stdin") + strlen(fileTypeExt[outputFormat]) + 2;
+        outputFile = calloc(len, sizeof(char));
+        if (outputFile != NULL)
+            snprintf(outputFile, len, "stdin.%s", fileTypeExt[outputFormat]);
+        else
+#endif
         {
             WSGO("Cannot allocate space for output file name\n");
             ACTION("Exiting\n");
             exit(1);
         }
-        sprintf(outputFile, "stdin.%s", fileTypeExt[outputFormat]);
     }
     else if ((outputFile == NULL) && (inputFile != NULL))
     {
         int len;
-        char *base, *ext;
+        const char *base, *ext;
 
         if (inputMap == NULL)
         {
@@ -767,7 +790,7 @@ parseArgs(int argc, char *argv[])
             base = inputMap;
 
         len = strlen(base) + strlen(fileTypeExt[outputFormat]) + 2;
-        outputFile = uTypedCalloc(len, char);
+        outputFile = calloc(len, sizeof(char));
         if (outputFile == NULL)
         {
             WSGO("Cannot allocate space for output file name\n");
@@ -776,7 +799,7 @@ parseArgs(int argc, char *argv[])
         }
         ext = strrchr(base, '.');
         if (ext == NULL)
-            sprintf(outputFile, "%s.%s", base, fileTypeExt[outputFormat]);
+            snprintf(outputFile, len, "%s.%s", base, fileTypeExt[outputFormat]);
         else
         {
             strcpy(outputFile, base);
@@ -786,14 +809,15 @@ parseArgs(int argc, char *argv[])
     else if (outputFile == NULL)
     {
         int len;
-        char *ch, *name, buf[128];
+        char *ch, buf[128];
+        const char *name = buf;
         if (inDpyName[0] == ':')
-            snprintf(name = buf, sizeof(buf), "server%s", inDpyName);
+            snprintf(buf, sizeof(buf), "server%s", inDpyName);
         else
             name = inDpyName;
 
         len = strlen(name) + strlen(fileTypeExt[outputFormat]) + 2;
-        outputFile = uTypedCalloc(len, char);
+        outputFile = calloc(len, sizeof(char));
         if (outputFile == NULL)
         {
             WSGO("Cannot allocate space for output file name\n");
@@ -828,7 +852,7 @@ parseArgs(int argc, char *argv[])
 }
 
 static Display *
-GetDisplay(char *program, char *dpyName)
+GetDisplay(const char *program, const char *dpyName)
 {
     int mjr, mnr, error;
     Display *dpy;
@@ -841,25 +865,25 @@ GetDisplay(char *program, char *dpyName)
         switch (error)
         {
         case XkbOD_BadLibraryVersion:
-            INFO3("%s was compiled with XKB version %d.%02d\n",
+            INFO("%s was compiled with XKB version %d.%02d\n",
                   program, XkbMajorVersion, XkbMinorVersion);
-            ERROR2("X library supports incompatible version %d.%02d\n",
+            ERROR("X library supports incompatible version %d.%02d\n",
                    mjr, mnr);
             break;
         case XkbOD_ConnectionRefused:
-            ERROR1("Cannot open display \"%s\"\n", dpyName);
+            ERROR("Cannot open display \"%s\"\n", dpyName);
             break;
         case XkbOD_NonXkbServer:
-            ERROR1("XKB extension not present on %s\n", dpyName);
+            ERROR("XKB extension not present on %s\n", dpyName);
             break;
         case XkbOD_BadServerVersion:
-            INFO3("%s was compiled with XKB version %d.%02d\n",
+            INFO("%s was compiled with XKB version %d.%02d\n",
                   program, XkbMajorVersion, XkbMinorVersion);
-            ERROR3("Server %s uses incompatible version %d.%02d\n",
+            ERROR("Server %s uses incompatible version %d.%02d\n",
                    dpyName, mjr, mnr);
             break;
         default:
-            WSGO1("Unknown error %d from XkbOpenDisplay\n", error);
+            WSGO("Unknown error %d from XkbOpenDisplay\n", error);
         }
     }
     else if (synch)
@@ -883,9 +907,10 @@ main(int argc, char *argv[])
     XkbFileInfo result;
     Status status;
 
-    yyin = stdin;
-    uSetEntryFile(NullString);
+    scan_set_file(stdin);
+#ifdef DEBUG
     uSetDebugFile(NullString);
+#endif
     uSetErrorFile(NullString);
 
     XkbInitIncludePath();
@@ -914,7 +939,7 @@ main(int argc, char *argv[])
     }
     if (inputFile != NULL)
     {
-        if (uStringEqual(inputFile, "-"))
+        if (strcmp(inputFile, "-") == 0)
         {
             file = stdin;
             inputFile = "stdin";
@@ -949,9 +974,9 @@ main(int argc, char *argv[])
         mnr = XkbMinorVersion;
         if (!XkbLibraryVersion(&mjr, &mnr))
         {
-            INFO3("%s was compiled with XKB version %d.%02d\n",
+            INFO("%s was compiled with XKB version %d.%02d\n",
                   argv[0], XkbMajorVersion, XkbMinorVersion);
-            ERROR2("X library supports incompatible version %d.%02d\n",
+            ERROR("X library supports incompatible version %d.%02d\n",
                    mjr, mnr);
             ACTION("Exiting\n");
             exit(1);
@@ -975,7 +1000,7 @@ main(int argc, char *argv[])
                 }
                 if (!mapToUse)
                 {
-                    FATAL2("No map named \"%s\" in \"%s\"\n",
+                    FATAL("No map named \"%s\" in \"%s\"\n",
                            inputMap, inputFile);
                     /* NOTREACHED */
                 }
@@ -994,16 +1019,16 @@ main(int argc, char *argv[])
                     mapToUse = rtrn;
                     if (warningLevel > 4)
                     {
-                        WARN1
+                        WARN
                             ("No map specified, but \"%s\" has several\n",
                              inputFile);
-                        ACTION1
+                        ACTION
                             ("Using the first defined map, \"%s\"\n",
                              mapToUse->name);
                     }
                 }
             }
-            bzero((char *) &result, sizeof(result));
+            bzero(&result, sizeof(result));
             result.type = mapToUse->type;
             if ((result.xkb = XkbAllocKeyboard()) == NULL)
             {
@@ -1038,7 +1063,7 @@ main(int argc, char *argv[])
                 ok = CompileGeometry(mapToUse, &result, MergeReplace);
                 break;
             default:
-                WSGO1("Unknown file type %d\n", mapToUse->type);
+                WSGO("Unknown file type %d\n", mapToUse->type);
                 ok = False;
                 break;
             }
@@ -1047,7 +1072,7 @@ main(int argc, char *argv[])
         else if (inputFormat == INPUT_XKM) /* parse xkm file */
         {
             unsigned tmp;
-            bzero((char *) &result, sizeof(result));
+            bzero(&result, sizeof(result));
             if ((result.xkb = XkbAllocKeyboard()) == NULL)
             {
                 WSGO("Cannot allocate keyboard description\n");
@@ -1056,20 +1081,20 @@ main(int argc, char *argv[])
             tmp = XkmReadFile(file, 0, XkmKeymapLegal, &result);
             if (tmp == XkmKeymapLegal)
             {
-                ERROR1("Cannot read XKM file \"%s\"\n", inputFile);
+                ERROR("Cannot read XKM file \"%s\"\n", inputFile);
                 ok = False;
             }
             result.xkb->device_spec = device_id;
         }
         else
         {
-            INFO1("Errors encountered in %s; not compiled.\n", inputFile);
+            INFO("Errors encountered in %s; not compiled.\n", inputFile);
             ok = False;
         }
     }
     else if (inDpy != NULL)
     {
-        bzero((char *) &result, sizeof(result));
+        bzero(&result, sizeof(result));
         result.type = XkmKeymapFile;
         result.xkb = XkbGetMap(inDpy, XkbAllMapComponentsMask, device_id);
         if (result.xkb == NULL)
@@ -1089,8 +1114,8 @@ main(int argc, char *argv[])
                 char buf[100];
                 buf[0] = '\0';
                 XGetErrorText(inDpy, status, buf, 100);
-                WARN1("Could not load keyboard geometry for %s\n", inDpyName);
-                ACTION1("%s\n", buf);
+                WARN("Could not load keyboard geometry for %s\n", inDpyName);
+                ACTION("%s\n", buf);
                 ACTION("Resulting keymap file will not describe geometry\n");
             }
         }
@@ -1110,13 +1135,13 @@ main(int argc, char *argv[])
         if ((inDpy != outDpy) &&
             (XkbChangeKbdDisplay(outDpy, &result) != Success))
         {
-            WSGO2("Error converting keyboard display from %s to %s\n",
+            WSGO("Error converting keyboard display from %s to %s\n",
                   inDpyName, outDpyName);
             exit(1);
         }
         if (outputFile != NULL)
         {
-            if (uStringEqual(outputFile, "-"))
+            if (strcmp(outputFile, "-") == 0)
                 outputFile = "stdout";
             else
             {
@@ -1150,7 +1175,7 @@ main(int argc, char *argv[])
                          | S_IWOTH | binMode);
                 if (outputFileFd < 0)
                 {
-                    ERROR1
+                    ERROR
                         ("Cannot open \"%s\" to write keyboard description\n",
                          outputFile);
                     ACTION("Exiting\n");
@@ -1165,7 +1190,7 @@ main(int argc, char *argv[])
                 /* end BR */
                 if (out == NULL)
                 {
-                    ERROR1
+                    ERROR
                         ("Cannot open \"%s\" to write keyboard description\n",
                          outputFile);
                     ACTION("Exiting\n");
@@ -1187,14 +1212,14 @@ main(int argc, char *argv[])
         case WANT_X_SERVER:
             if (!(ok = XkbWriteToServer(&result)))
             {
-                ERROR2("%s in %s\n", _XkbErrMessages[_XkbErrCode],
+                ERROR("%s in %s\n", _XkbErrMessages[_XkbErrCode],
                        _XkbErrLocation ? _XkbErrLocation : "unknown");
-                ACTION1("Couldn't write keyboard description to %s\n",
+                ACTION("Couldn't write keyboard description to %s\n",
                         outDpyName);
             }
             break;
         default:
-            WSGO1("Unknown output format %d\n", outputFormat);
+            WSGO("Unknown output format %d\n", outputFormat);
             ACTION("No output file created\n");
             ok = False;
             break;
@@ -1203,18 +1228,18 @@ main(int argc, char *argv[])
         {
             if (fclose(out))
             {
-                ERROR1("Cannot close \"%s\" properly (not enough space?)\n",
+                ERROR("Cannot close \"%s\" properly (not enough space?)\n",
                        outputFile);
                 ok= False;
             }
             else if (!ok)
             {
-                ERROR2("%s in %s\n", _XkbErrMessages[_XkbErrCode],
+                ERROR("%s in %s\n", _XkbErrMessages[_XkbErrCode],
                        _XkbErrLocation ? _XkbErrLocation : "unknown");
             }
             if (!ok)
             {
-                ACTION1("Output file \"%s\" removed\n", outputFile);
+                ACTION("Output file \"%s\" removed\n", outputFile);
                 unlink(outputFile);
             }
         }
